@@ -13,7 +13,7 @@ import beanstalk
 from beanstalk.tasks.utils import (set_verbose_level, load_role_settings as load_beanstalk_settings,
                                    load_web_servers, run_hooked_actions)
 from beanstalk.decorators import beanstalk_role
-from beanstalk.titles import section_title, tool_title, separator
+from beanstalk.console.titles import section_title, tool_title, separator
 from beanstalk.validator import validate_web_server, validate_file_existence, validate_project_type, supported_projects
 
 
@@ -136,7 +136,7 @@ def plant(VERBOSE=0):
 
 @task
 @beanstalk_role('app')
-def deploy(settings_path=None, **settings_patches):
+def deploy(**settings_patches):
     """Deploy project in current work folder to beanstalk-stack
     """
     # Set variables
@@ -145,7 +145,7 @@ def deploy(settings_path=None, **settings_patches):
 
     # Load beanstalk settings
     settings_patches = eval_kwargs(settings_patches)
-    beanstalk_settings = load_beanstalk_settings(local_settings_path=settings_path, **settings_patches)
+    beanstalk_settings = load_beanstalk_settings(**settings_patches)
 
     # Get variables from settings
     project_name = beanstalk_settings['PROJECT_NAME']
@@ -224,6 +224,7 @@ def deploy(settings_path=None, **settings_patches):
                 execute(deploy_remote_core)
                 env.in_remote = False
             print separator('+')
+            print ''
 
             # Call post-deploy script
             if run_hooked_actions('POST_DEPLOY_ACTIONS'):
@@ -261,7 +262,7 @@ def deploy_remote_core():
     run_hooked_actions('PRE_INSTALL_ACTIONS')
 
     # Create this app to server
-    print section_title('Find room for %s' % project_name)
+    print section_title('Find room for {name} in {host}'.format(name=project_name, host=host_name))
     run('bsjack server.create_app:{project_name},VERBOSE={verbose:d} --hide=status'.format(
         project_name=project_name, verbose=beanstalk_settings['VERBOSE']))
 
